@@ -5,7 +5,7 @@ import sys
 from setuptools import setup
 
 # version of pycurl-client, should match current DBS release tag
-package_version = "3.17.0.1"
+package_version = "3.17.1"
 
 # Requirements file for pip dependencies
 requirements = "requirements.txt"
@@ -34,8 +34,8 @@ setup(name="dbs3-pycurl",
                 'RestClient.ErrorHandling',
                 'RestClient.ProxyPlugins',
                 'RestClient.RequestHandling'],
-      package_dir={'': 'src/python'},
+      package_dir={'': 'src/python/'},
       install_requires=parse_requirements(requirements),
-      url="https://github.com/dmwm/DBS",
+      url="https://github.com/dmwm/PycurlClient/tree/3.17.1",
       license="Apache License, Version 2.0",
       )
